==> haskell-numbers-3000.2.0.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 numbers
version:              3000.2.0.2
visibility:           public
id:                   numbers-3000.2.0.2-8aIYozru23LJY5Df3WcQDx
key:                  numbers-3000.2.0.2-8aIYozru23LJY5Df3WcQDx
license:              BSD-3-Clause
maintainer:           johnw@newartisans.com
author:               Lennart Augustsson
homepage:             https://github.com/jwiegley/numbers#readme
synopsis:             Various number types
description:
    Instances of the numerical classes for a variety of
    different numbers: (computable) real numbers,
    arbitrary precision fixed numbers,
    arbitrary precision floating point numbers,
    differentiable numbers, symbolic numbers,
    natural numbers, interval arithmetic.

category:             Data, Math
abi:                  2551331f8027073fd68e8dd699cccd1b
exposed:              True
exposed-modules:
    Data.Number.BigFloat Data.Number.CReal Data.Number.Dif
    Data.Number.Fixed Data.Number.FixedFunctions Data.Number.Interval
    Data.Number.Natural Data.Number.Symbolic Data.Number.Vectorspace

import-dirs:          /usr/lib/ghc-9.0.2/site-local/numbers-3000.2.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/numbers-3000.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numbers
hs-libraries:         HSnumbers-3000.2.0.2-8aIYozru23LJY5Df3WcQDx
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-numbers/html/numbers.haddock
haddock-html:         /usr/share/doc/haskell-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-numbers-3000.2.0.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 numbers
version:              3000.2.0.2
visibility:           public
id:                   numbers-3000.2.0.2-8yZ4oMndZXG9iGYKi4cjLy
key:                  numbers-3000.2.0.2-8yZ4oMndZXG9iGYKi4cjLy
license:              BSD-3-Clause
maintainer:           johnw@newartisans.com
author:               Lennart Augustsson
homepage:             https://github.com/jwiegley/numbers#readme
synopsis:             Various number types
description:
    Instances of the numerical classes for a variety of
    different numbers: (computable) real numbers,
    arbitrary precision fixed numbers,
    arbitrary precision floating point numbers,
    differentiable numbers, symbolic numbers,
    natural numbers, interval arithmetic.

category:             Data, Math
abi:                  b70db8c9e8b1e4616012c16a53702bb3
exposed:              True
exposed-modules:
    Data.Number.BigFloat Data.Number.CReal Data.Number.Dif
    Data.Number.Fixed Data.Number.FixedFunctions Data.Number.Interval
    Data.Number.Natural Data.Number.Symbolic Data.Number.Vectorspace

import-dirs:          /usr/lib/ghc-9.0.2/site-local/numbers-3000.2.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/numbers-3000.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numbers
hs-libraries:         HSnumbers-3000.2.0.2-8yZ4oMndZXG9iGYKi4cjLy
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-numbers/html/numbers.haddock
haddock-html:         /usr/share/doc/haskell-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
